package com.sas.tutorials.scoringapi

class Loan {

    Double bad
    Double loan
    Double mortdue
    Double val
    String reason
    String job
    Double yoj
    Double derog
    Double delinq
    Double clage
    Double ninq
    Double clno
    Double debtinc

    String score

    static transients = ['score']

    static contstraints = { 
        bad(blank:true, nullable:true) 
        loan(blank:true, nullable:true) 
        mortdue(blank:true, nullable:true) 
        val(blank:true, nullable:true) 
        reason(blank:true, nullable:true) 
        job(blank:true, nullable:true, inList:['Mgr','Office','Other','ProfExe','Sales','Self'])
        yoj(blank:true, nullable:true)
        derog(blank:true, nullable:true)
        delinq(blank:true, nullable:true)
        clage(blank:true, nullable:true)
        ninq(blank:true, nullable:true)
        clno(blank:true, nullable:true)
        debtinc(blank:true, nullable:true)
    } 

// **************************************************************************** 
// Variable  Role    Level     Description 
// --------  ------  -------   ------------------------------ 
// BAD       target  binary    Currently in default or seriously delinquent 
// REASON    input   binary    Home improvement or debt consolidation
// JOB       input   nominal   One of: Mgr, Office, Other, ProfExe, Sales, Self
// LOAN      input   interval  Amount of current loan request
// MORTDUE   input   interval  Amount due on existing mortgage 
// VALUE     input   interval  Value of current property
// DEBTINC   input   interval  Debt to income ratio 
// YOJ       input   interval  Years on current job
// DEROG     input   interval  Number of major derogatory reports
// CLNO      input   interval  Number of trade (credit) lines
// DELINQ    input   interval  Number of delinquent trade lines
// CLAGE     input   interval  Age of oldest trade line in months
// NINQ      input   interval  Number of recent credit inquiries
//*****************************************************************************

    static mapping = {
        table "hmeqid"
        version false
        id      column:'custid'
        bad     column:'BAD'
        loan    column:'LOAN'
        mortdue column:'MORTDUE';
        val     column:'"VALUE"';
        reason  column:'REASON'
        job     column:'JOB'
        yoj     column:'YOJ'
        derog   column:'DEROG'
        delinq  column:'DELINQ'
        clage   column:'CLAGE'
        ninq    column:'NINQ'
        clno    column:'CLNO'
        debtinc column:'DEBTINC'
    }

    String toString() { 
        return id 
    } 

}
